+
@@ -72,7 +72,7 @@ export function main() {
class AppComponent {
list:List;
testingPlainComponents:boolean;
- testingWithDecorators:boolean;
+ testingWithDirectives:boolean;
testingDynamicComponents:boolean;
constructor() {
@@ -82,7 +82,7 @@ class AppComponent {
reset():void {
this.list = [];
this.testingPlainComponents = false;
- this.testingWithDecorators = false;
+ this.testingWithDirectives = false;
this.testingDynamicComponents = false;
}
@@ -91,9 +91,9 @@ class AppComponent {
this.testingPlainComponents = true;
}
- createComponentsWithDecorators():void {
+ createComponentsWithDirectives():void {
this.list = testList;
- this.testingWithDecorators = true;
+ this.testingWithDirectives = true;
}
createDynamicComponents():void {
@@ -106,8 +106,8 @@ class AppComponent {
@View({template: `
`})
class DummyComponent {}
-@Decorator({selector: '[dummy-decorator]'})
-class DummyDecorator {}
+@Directive({selector: '[dummy-decorator]'})
+class DummyDirective {}
@Component({selector: 'dynamic-dummy'})
class DynamicDummy {
diff --git a/modules/benchmarks/src/largetable/largetable_benchmark.js b/modules/benchmarks/src/largetable/largetable_benchmark.js
index a3030d53c5..2a96e2bb24 100644
--- a/modules/benchmarks/src/largetable/largetable_benchmark.js
+++ b/modules/benchmarks/src/largetable/largetable_benchmark.js
@@ -2,7 +2,7 @@ import {bootstrap} from 'angular2/angular2';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
import {LifeCycle} from 'angular2/src/core/life_cycle/life_cycle';
diff --git a/modules/benchmarks/src/naive_infinite_scroll/app.js b/modules/benchmarks/src/naive_infinite_scroll/app.js
index 9854bfc8c4..94c66359e0 100644
--- a/modules/benchmarks/src/naive_infinite_scroll/app.js
+++ b/modules/benchmarks/src/naive_infinite_scroll/app.js
@@ -9,7 +9,7 @@ import {document} from 'angular2/src/facade/browser';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({selector: 'scroll-app'})
diff --git a/modules/benchmarks/src/naive_infinite_scroll/cells.js b/modules/benchmarks/src/naive_infinite_scroll/cells.js
index fdb0b9d959..7eff183cef 100644
--- a/modules/benchmarks/src/naive_infinite_scroll/cells.js
+++ b/modules/benchmarks/src/naive_infinite_scroll/cells.js
@@ -5,7 +5,7 @@ import {For} from 'angular2/directives';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
export class HasStyle {
diff --git a/modules/benchmarks/src/naive_infinite_scroll/scroll_area.js b/modules/benchmarks/src/naive_infinite_scroll/scroll_area.js
index b034466fb0..406fce747b 100644
--- a/modules/benchmarks/src/naive_infinite_scroll/scroll_area.js
+++ b/modules/benchmarks/src/naive_infinite_scroll/scroll_area.js
@@ -3,7 +3,7 @@ import {Math} from 'angular2/src/facade/math';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
import {Offering, ITEMS, ITEM_HEIGHT, VISIBLE_ITEMS, VIEW_PORT_HEIGHT,
diff --git a/modules/benchmarks/src/naive_infinite_scroll/scroll_item.js b/modules/benchmarks/src/naive_infinite_scroll/scroll_item.js
index e1c2982470..9a4719ec35 100644
--- a/modules/benchmarks/src/naive_infinite_scroll/scroll_item.js
+++ b/modules/benchmarks/src/naive_infinite_scroll/scroll_item.js
@@ -5,7 +5,7 @@ import {CompanyNameComponent, OpportunityNameComponent,
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
import {Offering, ITEM_HEIGHT, COMPANY_NAME_WIDTH, OPPORTUNITY_NAME_WIDTH,
diff --git a/modules/benchmarks/src/tree/tree_benchmark.js b/modules/benchmarks/src/tree/tree_benchmark.js
index ed40e79f83..dd26f42a8d 100644
--- a/modules/benchmarks/src/tree/tree_benchmark.js
+++ b/modules/benchmarks/src/tree/tree_benchmark.js
@@ -2,7 +2,7 @@ import {bootstrap, ViewContainerRef, Compiler} from 'angular2/angular2';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
import {LifeCycle} from 'angular2/src/core/life_cycle/life_cycle';
diff --git a/modules/benchmarks_external/src/compiler/compiler_benchmark.dart b/modules/benchmarks_external/src/compiler/compiler_benchmark.dart
index 3ca68551fd..e8b1fab154 100644
--- a/modules/benchmarks_external/src/compiler/compiler_benchmark.dart
+++ b/modules/benchmarks_external/src/compiler/compiler_benchmark.dart
@@ -58,7 +58,7 @@ createTemplate(String html) {
return div;
}
-@Decorator(
+@Directive(
selector: '[dir0]',
map: const {
'attr0': '=>prop'
@@ -68,7 +68,7 @@ class Dir0 {
Object prop;
}
-@Decorator(
+@Directive(
selector: '[dir1]',
map: const {
'attr1': '=>prop'
@@ -81,7 +81,7 @@ class Dir1 {
}
}
-@Decorator(
+@Directive(
selector: '[dir2]',
map: const {
'attr2': '=>prop'
@@ -94,7 +94,7 @@ class Dir2 {
}
}
-@Decorator(
+@Directive(
selector: '[dir3]',
map: const {
'attr3': '=>prop'
@@ -107,7 +107,7 @@ class Dir3 {
}
}
-@Decorator(
+@Directive(
selector: '[dir4]',
map: const {
'attr4': '=>prop'
diff --git a/modules/examples/src/forms/index.es6 b/modules/examples/src/forms/index.es6
index 42d83aaed6..422f10da6d 100644
--- a/modules/examples/src/forms/index.es6
+++ b/modules/examples/src/forms/index.es6
@@ -3,7 +3,7 @@ import {FormBuilder, Validators, FormDirectives, ControlGroup} from 'angular2/fo
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
// HeaderFields renders the bound header control group. It can used as follows:
diff --git a/modules/examples/src/material/button/index.js b/modules/examples/src/material/button/index.js
index ffa4a0e541..4272defcd6 100644
--- a/modules/examples/src/material/button/index.js
+++ b/modules/examples/src/material/button/index.js
@@ -6,7 +6,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/material/checkbox/index.js b/modules/examples/src/material/checkbox/index.js
index 0c099e9fb4..529dcca63c 100644
--- a/modules/examples/src/material/checkbox/index.js
+++ b/modules/examples/src/material/checkbox/index.js
@@ -6,7 +6,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/material/grid_list/index.js b/modules/examples/src/material/grid_list/index.js
index bb0bbf8832..09f931e35e 100644
--- a/modules/examples/src/material/grid_list/index.js
+++ b/modules/examples/src/material/grid_list/index.js
@@ -6,7 +6,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/material/input/index.js b/modules/examples/src/material/input/index.js
index 0c099e9fb4..529dcca63c 100644
--- a/modules/examples/src/material/input/index.js
+++ b/modules/examples/src/material/input/index.js
@@ -6,7 +6,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/material/progress-linear/index.js b/modules/examples/src/material/progress-linear/index.js
index 7894814454..d72ff6105d 100644
--- a/modules/examples/src/material/progress-linear/index.js
+++ b/modules/examples/src/material/progress-linear/index.js
@@ -6,7 +6,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/material/radio/index.js b/modules/examples/src/material/radio/index.js
index 79798177f9..d96658b00f 100644
--- a/modules/examples/src/material/radio/index.js
+++ b/modules/examples/src/material/radio/index.js
@@ -7,7 +7,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/material/switcher/index.js b/modules/examples/src/material/switcher/index.js
index cfacd7aa1c..91e8b9dfd0 100644
--- a/modules/examples/src/material/switcher/index.js
+++ b/modules/examples/src/material/switcher/index.js
@@ -6,7 +6,7 @@ import {bind} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/todo/index.js b/modules/examples/src/todo/index.js
index ef447c841f..e4bd564639 100644
--- a/modules/examples/src/todo/index.js
+++ b/modules/examples/src/todo/index.js
@@ -5,7 +5,7 @@ import {ReflectionCapabilities} from 'angular2/src/reflection/reflection_capabil
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
@Component({
diff --git a/modules/examples/src/hello_world/index_common.js b/modules/examples/src/hello_world/index_common.js
index e4e360e495..745466c3f4 100644
--- a/modules/examples/src/hello_world/index_common.js
+++ b/modules/examples/src/hello_world/index_common.js
@@ -3,14 +3,14 @@ import {Injectable} from 'angular2/di';
// TODO(radokirov): Once the application is transpiled by TS instead of Traceur,
// add those imports back into 'angular2/angular2';
-import {Component, Decorator} from 'angular2/src/core/annotations_impl/annotations';
+import {Component, Directive} from 'angular2/src/core/annotations_impl/annotations';
import {View} from 'angular2/src/core/annotations_impl/view';
// Angular 2.0 supports 2 basic types of directives:
// - Component - the basic building blocks of Angular 2.0 apps. Backed by
// ShadowDom.(http://www.html5rocks.com/en/tutorials/webcomponents/shadowdom/)
// - Decorator - add behavior to existing elements.
// @Component is AtScript syntax to annotate the HelloCmp class as an Angular
// 2.0 component.
@@ -45,9 +45,9 @@ export class HelloCmp {
}
}
-// Decorators are light-weight. They don't allow new
+// Directives are light-weight. They don't allow new
// expression contexts (use @Component for those needs).
-@Decorator({
+@Directive({
selector: '[red]'
})
class RedDec {
@@ -3,14 +3,14 @@ import {Injectable} from 'angular2/di';
// - Component - the basic building blocks of Angular 2.0 apps. Backed by
// ShadowDom.(http://www.html5rocks.com/en/tutorials/webcomponents/shadowdom/)
-// - Decorator - add behavior to existing elements.
+// - Directive - add behavior to existing elements.
// @Component is AtScript syntax to annotate the HelloCmp class as an Angular
// 2.0 component.